@@ -31,6 +31,7 @@ class TickerDax:
             connect=True,
             log_connection=True,
             force=False,
+            enable_runtime_cache=True,
             disable_logging=False,
             debug=False
     ):
@@ -52,6 +53,7 @@ class TickerDax:
         self._fast_start = fast_start
         self._log_connection = log_connection
         self._force = force
+        self._enable_runtime_cache = enable_runtime_cache
         self._debug = debug
 
         # rest api configuration
@@ -133,19 +135,15 @@ class TickerDax:
             sock.bind(('', 0))
             return sock.getsockname()[1]
 
-    def _get_from_runtime_cache(self, route, symbols, since, till, timeframe):
+    def _get_from_runtime_cache(self, keys):
         """
         Get data from the runtime cache.
 
-        :param str route: The data route.
-        :param list[str] symbols: A list of symbols.
-        :param datetime since: The UTC start time.
-        :param datetime till: The UTC end time.
-        :param str timeframe: The time interval.
+        :param list[str] keys: A complete list of all the cache keys.
         :returns: The sorted result.
         :rtype list
         """
-        return self._runtime_cache.get(f'{route}{symbols}{since}{till}{timeframe}')
+        return [self._runtime_cache.get(key) for key in keys if self._runtime_cache.get(key)]
 
     def _get_from_cache(self, keys):
         """
@@ -189,18 +187,17 @@ class TickerDax:
         # return the needed rest requests
         return rest_requests
 
-    def _update_runtime_cache(self, route, symbols, since, till, timeframe, result):
+    def _update_runtime_cache(self, route, timeframe, results):
         """
         Set the result data in the runtime cache.
 
         :param str route: The data route.
-        :param list[str] symbols: A list of symbols.
-        :param datetime since: The UTC start time.
-        :param datetime till: The UTC end time.
         :param str timeframe: The time interval.
-        :param list[dict] result: The resulting data from the get_route request.
+        :param list[dict] results: The resulting data from the get_route request.
         """
-        self._runtime_cache[f'{route}{symbols}{since}{till}{timeframe}'] = result
+        if self._enable_runtime_cache:
+            for result in results:
+                self._runtime_cache[f'{NAME}/{route}/{result["symbol"]}/{timeframe}/{result["timestamp"]}'] = result
 
     def _setup_logger(self):
         """
@@ -634,11 +631,6 @@ class TickerDax:
         since = formatting.get_unix_time(since, timeframe)
         till = formatting.get_unix_time(till, timeframe)
 
-        # first check the runtime cache and see this result was already cached
-        cached_result = self._get_from_runtime_cache(route, symbols, since, till, timeframe)
-        if cached_result:
-            return cached_result
-
         # clear out which values are being tracked as cached, rest, or missing values
         self.cached_values.clear()
         self.rest_values.clear()
@@ -648,6 +640,13 @@ class TickerDax:
         timestamps = formatting.get_timestamp_range(since, till, timeframe)
         keys = self._get_cache_keys(route, symbols, timestamps, timeframe)
 
+        if self._enable_runtime_cache:
+            # first check the runtime cache and see this result was already cached
+            cached_results = self._get_from_runtime_cache(keys)
+            # return the cached results only if they all exist
+            if len(cached_results) == len(keys):
+                return cached_results
+
         # get the cached values and determine which rest requests are outstanding
         self._logger.debug(f'Checking "{route}" cache for {symbols}...')
         outstanding_rest_requests = self._get_from_cache(keys)
@@ -658,12 +657,12 @@ class TickerDax:
         else:
             self.rest_values = self._request(route, outstanding_rest_requests, timeframe)
 
-        result = sorted(self._update_cache(route, keys), key=lambda i: i['timestamp'])
+        results = sorted(self._update_cache(route, keys), key=lambda i: i['timestamp'])
 
         # update the runtime cache so that data is not re-requested within the same runtime
-        self._update_runtime_cache(route, symbols, since, till, timeframe, result)
+        self._update_runtime_cache(route, timeframe, results)
 
-        return result
+        return results
 
     def report_error(self, message):
         """
@@ -692,8 +691,8 @@ if __name__ == '__main__':
     client = TickerDax()
 
     pprint(client.get_route(
-        route='order-book/predictions/v1/10',
-        symbols=['BTC'],
+        route='order-book/predictions/v1/50',
+        symbols=['BTC', 'LTC'],
         timeframe='1h',
         since=datetime.now(tz=timezone.utc) - timedelta(hours=6),
         till=datetime.now(tz=timezone.utc)
@@ -701,6 +700,6 @@ if __name__ == '__main__':
 
     # client.stream(
     #     routes={
-    #         'order-book/predictions/v1/10': ['BTC', 'LTC'],
+    #         'order-book/predictions/v1/50': ['BTC', 'LTC'],
     #     },
     # )
